==> deepin-graphics-driver-manager_1.1.8.orig.tar.xz: deepin-graphics-driver-manager-1.1.8/translations/deepin-graphics-driver-manager_sr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sr" version="2.1">
<context>
    <name>GLTestWindow</name>
    <message>
        <location filename="../gltest/main.cpp" line="124"/>
        <source>Apply</source>
        <translation>Примени</translation>
    </message>
    <message>
        <location filename="../gltest/main.cpp" line="125"/>
        <source>Cancel</source>
        <translation>Откажи</translation>
    </message>
    <message>
        <location filename="../gltest/main.cpp" line="126"/>
        <source>Please ensure the driver works normally without blurred screen and screen tearing</source>
        <translation>Уверите се да управљачки програм ради нормално без замућења и цепања приказа</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="41"/>
        <source>Switch</source>
        <translation>Пређи</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="58"/>
        <source>OK</source>
        <translation>У реду</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="62"/>
        <source>Reboot</source>
        <translation>Поново покрени</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="177"/>
        <source>Your hardware is not supported currently, please wait for future version.</source>
        <translation>Ваш уређај тренутно није подржан, молимо сачекајте будућу верзију.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="267"/>
        <source>Downloading</source>
        <translation>Преузимање</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="269"/>
        <source>Downloading the driver for %1, please wait...</source>
        <translation>Преузимање управљачког програма за %1, молимо сачекајте...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="298"/>
        <source>Download Successful</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="300"/>
        <source>Please reboot to test the driver.

If no signal, please confirm whether the monitor output port is connected correctly.</source>
        <translation>Поново покрените да тестирате управљач.

Ако нема сигнала, проверите да ли је прикључак видео излаза правилно намештен.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="302"/>
        <source>Please reboot to test the driver</source>
        <translation>Поново покрените да тестирате управљачки програм</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="290"/>
        <source>Download failed</source>
        <translation>Неуспешно преузимање</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="38"/>
        <source>Dark theme</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="291"/>
        <source>Sorry, switch failed</source>
        <translation>Извините, прелазак није успео</translation>
    </message>
</context>
<context>
    <name>Resolution</name>
    <message>
        <location filename="../resolutions/resolution.cpp" line="8"/>
        <source>Use AMD card driver</source>
        <translation>Користи AMD управљач картица</translation>
    </message>
    <message>
        <location filename="../resolutions/resolution.cpp" line="9"/>
        <source>For special needs. Auto determine the acceleration way without external configuration.</source>
        <translation>За посебне потребе. Аутоматски одређује начин убрзања без спољњег подешавања.</translation>
    </message>
    <message>
        <location filename="../resolutions/resolution.cpp" line="11"/>
        <source>NVIDIA Default Driver</source>
        <translation>NVIDIA подразумевани управљач</translation>
    </message>
    <message>
        <location filename="../resolutions/resolution.cpp" line="14"/>
        <source>NVIDIA Open Source Driver</source>
        <translation>NVIDIA управљач отвореног кода</translation>
    </message>
    <message>
        <location filename="../resolutions/resolution.cpp" line="17"/>
        <source>NVIDIA Closed Source Driver</source>
        <translation>NVIDIA власнички управљач</translation>
    </message>
    <message>
        <location filename="../resolutions/resolution.cpp" line="19"/>
        <source>Only adaptive to parts of distributions and graphics cards, may cause black screen.</source>
        <translation>Прилагодљив само делу дистрибуција и графичких картица, може изазвати црни екран.</translation>
    </message>
    <message>
        <location filename="../resolutions/resolution.cpp" line="21"/>
        <source>Intel Default Driver</source>
        <translation>Intel подразумевани управљач</translation>
    </message>
    <message>
        <location filename="../resolutions/resolution.cpp" line="24"/>
        <source>Intel Compatible Mode</source>
        <translation>Intel режим компатибилности</translation>
    </message>
    <message>
        <location filename="../resolutions/resolution.cpp" line="25"/>
        <source>Use Intel compatible mode</source>
        <translation>Користи Intel режим компатибилности</translation>
    </message>
    <message>
        <location filename="../resolutions/resolution.cpp" line="12"/>
        <source>Use default driver</source>
        <translation>Користи подразумевани управљач</translation>
    </message>
    <message>
        <location filename="../resolutions/resolution.cpp" line="13"/>
        <source>NVIDIA driver is not detected in the current environment, and NVIDIA card will not work properly.</source>
        <translation>NVIDIA управљач није откривен у тренутном окружењу и NVIDIA картица неће правилно радити.</translation>
    </message>
    <message>
        <location filename="../resolutions/resolution.cpp" line="15"/>
        <source>Use open source driver</source>
        <translation>Користи управљач отвореног кода</translation>
    </message>
    <message>
        <location filename="../resolutions/resolution.cpp" line="16"/>
        <source>Poor performance, unstable in some graphics cards.</source>
        <translation>Слаб учинак, нестабилан са неким графичким картицама.</translation>
    </message>
    <message>
        <location filename="../resolutions/resolution.cpp" line="18"/>
        <source>Use closed source driver</source>
        <translation>Користи власнички управљач</translation>
    </message>
    <message>
        <location filename="../resolutions/resolution.cpp" line="22"/>
        <source>Use Intel default driver</source>
        <translation>Користи Intel подразумевани управљач</translation>
    </message>
    <message>
        <location filename="../resolutions/resolution.cpp" line="23"/>
        <source>Poor compatibility for parts of old graphics cards.</source>
        <translation>Слаба компатибилност са делом старијих графичких картица.</translation>
    </message>
    <message>
        <location filename="../resolutions/resolution.cpp" line="26"/>
        <source>Best compatibility for all Intel graphics cards to accelerate, but performance is relatively weak.</source>
        <translation>Највећа компатибилност за убрзање са свим Интеловим графичким картицама, али учинак је релативно слаб.</translation>
    </message>
    <message>
        <location filename="../resolutions/resolution.cpp" line="27"/>
        <source>Intel Acceleration Mode</source>
        <translation>Intel режим убрзања</translation>
    </message>
    <message>
        <location filename="../resolutions/resolution.cpp" line="28"/>
        <source>Use Intel acceleration mode</source>
        <translation>Користи Intel режим убрзања</translation>
    </message>
    <message>
        <location filename="../resolutions/resolution.cpp" line="29"/>
        <source>Speed up the graphics card with better performance, but unstable in some cards with screen flashing.</source>
        <translation>Убрзајте графичку картицу са бољим учинком, али нестабилно са неким картицама уз треперење екрана.</translation>
    </message>
    <message>
        <location filename="../resolutions/resolution.cpp" line="31"/>
        <source>Use Bumblebee Solution</source>
        <translation>Користи Bumblebee решење</translation>
    </message>
    <message>
        <location filename="../resolutions/resolution.cpp" line="32"/>
        <source>Bumblebee Solution</source>
        <translation>Bumblebee решење</translation>
    </message>
    <message>
        <location filename="../resolutions/resolution.cpp" line="33"/>
        <source>Save power to reduce power consumption.</source>
        <translation>Штедите енергију да смањите потрошњу.</translation>
    </message>
    <message>
        <location filename="../resolutions/resolution.cpp" line="35"/>
        <source>Use NV-PRIME Solution</source>
        <translation>Користи NV-PRIME решење</translation>
    </message>
    <message>
        <location filename="../resolutions/resolution.cpp" line="36"/>
        <source>PRIME Solution</source>
        <translation>PRIME решење</translation>
    </message>
    <message>
        <location filename="../resolutions/resolution.cpp" line="37"/>
        <source>For laptops with hybrid graphics, having best performance but must work with closed-source driver.</source>
        <translation>За преносне рачунаре са хибридном графиком. Има најбољи учинак, али мора радити са власничким управљачким програмом.</translation>
    </message>
</context>
<context>
    <name>ResolutionWidget</name>
    <message>
        <location filename="../widgets/resolutionwidget.cpp" line="118"/>
        <source>Version: </source>
        <translation>Верзија:</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../installer/main.cpp" line="37"/>
        <source>Congratulations, you have switched to %1, please reboot to take effect.</source>
        <translation>Честитамо! Прешли сте на %1. Поново покрените да ступи на снагу.</translation>
    </message>
    <message>
        <location filename="../installer/main.cpp" line="40"/>
        <source>Cancel</source>
        <translation>Откажи</translation>
    </message>
    <message>
        <location filename="../installer/main.cpp" line="41"/>
        <source>Reboot</source>
        <translation>Поново покрени</translation>
    </message>
    <message>
        <location filename="../installer/main.cpp" line="58"/>
        <source>Auto restore to %2 after failed to switch to %1</source>
        <translation>Аутоматски врати на %2 након неуспешног преласка на %1</translation>
    </message>
    <message>
        <location filename="../installer/main.cpp" line="61"/>
        <source>Submit Feedback</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../installer/main.cpp" line="69"/>
        <source>Updating the driver, please wait...</source>
        <translation>Ажурирање управљача, молимо сачекајте...</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="25"/>
        <source>Deepin Graphics Driver Manager</source>
        <translation>Управник Управљачких Програма</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="26"/>
        <source>Deepin Graphics Driver Manager is a compact and easy to use graphics driver management tool. It includes graphics card hardware detection, graphics driver installation, graphics driver solution switching,  graphics driver automatic recovery and other functions.</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> deepin-graphics-driver-manager_5.0.0.orig.tar.xz: deepin-graphics-driver-manager-5.0.0/translations/deepin-graphics-driver-manager_sr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sr" version="2.1">
<context>
    <name>GLTestWindow</name>
    <message>
        <location filename="../gltest/main.cpp" line="124"/>
        <source>Apply</source>
        <translation>Примени</translation>
    </message>
    <message>
        <location filename="../gltest/main.cpp" line="125"/>
        <source>Cancel</source>
        <translation>Откажи</translation>
    </message>
    <message>
        <location filename="../gltest/main.cpp" line="126"/>
        <source>Please ensure the driver works normally without blurred screen and screen tearing</source>
        <translation>Уверите се да управљачки програм ради нормално без замућења и цепања приказа</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="41"/>
        <source>Switch</source>
        <translation>Пређи</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="58"/>
        <source>OK</source>
        <translation>У реду</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="62"/>
        <source>Reboot</source>
        <translation>Поново покрени</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="177"/>
        <source>Your hardware is not supported currently, please wait for future version.</source>
        <translation>Ваш уређај тренутно није подржан, молимо сачекајте будућу верзију.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="267"/>
        <source>Downloading</source>
        <translation>Преузимање</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="269"/>
        <source>Downloading the driver for %1, please wait...</source>
        <translation>Преузимање управљачког програма за %1, молимо сачекајте...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="298"/>
        <source>Download Successful</source>
        <translation>Успешно преузимање</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="300"/>
        <source>Please reboot to test the driver.

If no signal, please confirm whether the monitor output port is connected correctly.</source>
        <translation>Поново покрените да тестирате управљач.

Ако нема сигнала, проверите да ли је прикључак видео излаза правилно намештен.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="302"/>
        <source>Please reboot to test the driver</source>
        <translation>Поново покрените да тестирате управљачки програм</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="290"/>
        <source>Download failed</source>
        <translation>Неуспешно преузимање</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="38"/>
        <source>Dark theme</source>
        <translation>Тамна тема</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="291"/>
        <source>Sorry, switch failed</source>
        <translation>Извините, прелазак није успео</translation>
    </message>
</context>
<context>
    <name>Resolution</name>
    <message>
        <location filename="../resolutions/resolution.cpp" line="8"/>
        <source>Use AMD card driver</source>
        <translation>Користи AMD управљач картица</translation>
    </message>
    <message>
        <location filename="../resolutions/resolution.cpp" line="9"/>
        <source>For special needs. Auto determine the acceleration way without external configuration.</source>
        <translation>За посебне потребе. Аутоматски одређује начин убрзања без спољњег подешавања.</translation>
    </message>
    <message>
        <location filename="../resolutions/resolution.cpp" line="11"/>
        <source>NVIDIA Default Driver</source>
        <translation>NVIDIA подразумевани управљач</translation>
    </message>
    <message>
        <location filename="../resolutions/resolution.cpp" line="14"/>
        <source>NVIDIA Open Source Driver</source>
        <translation>NVIDIA управљач отвореног кода</translation>
    </message>
    <message>
        <location filename="../resolutions/resolution.cpp" line="17"/>
        <source>NVIDIA Closed Source Driver</source>
        <translation>NVIDIA власнички управљач</translation>
    </message>
    <message>
        <location filename="../resolutions/resolution.cpp" line="19"/>
        <source>Only adaptive to parts of distributions and graphics cards, may cause black screen.</source>
        <translation>Прилагодљив само делу дистрибуција и графичких картица, може изазвати црни екран.</translation>
    </message>
    <message>
        <location filename="../resolutions/resolution.cpp" line="21"/>
        <source>Intel Default Driver</source>
        <translation>Intel подразумевани управљач</translation>
    </message>
    <message>
        <location filename="../resolutions/resolution.cpp" line="24"/>
        <source>Intel Compatible Mode</source>
        <translation>Intel режим компатибилности</translation>
    </message>
    <message>
        <location filename="../resolutions/resolution.cpp" line="25"/>
        <source>Use Intel compatible mode</source>
        <translation>Користи Intel режим компатибилности</translation>
    </message>
    <message>
        <location filename="../resolutions/resolution.cpp" line="12"/>
        <source>Use default driver</source>
        <translation>Користи подразумевани управљач</translation>
    </message>
    <message>
        <location filename="../resolutions/resolution.cpp" line="13"/>
        <source>NVIDIA driver is not detected in the current environment, and NVIDIA card will not work properly.</source>
        <translation>NVIDIA управљач није откривен у тренутном окружењу и NVIDIA картица неће правилно радити.</translation>
    </message>
    <message>
        <location filename="../resolutions/resolution.cpp" line="15"/>
        <source>Use open source driver</source>
        <translation>Користи управљач отвореног кода</translation>
    </message>
    <message>
        <location filename="../resolutions/resolution.cpp" line="16"/>
        <source>Poor performance, unstable in some graphics cards.</source>
        <translation>Слаб учинак, нестабилан са неким графичким картицама.</translation>
    </message>
    <message>
        <location filename="../resolutions/resolution.cpp" line="18"/>
        <source>Use closed source driver</source>
        <translation>Користи власнички управљач</translation>
    </message>
    <message>
        <location filename="../resolutions/resolution.cpp" line="22"/>
        <source>Use Intel default driver</source>
        <translation>Користи Intel подразумевани управљач</translation>
    </message>
    <message>
        <location filename="../resolutions/resolution.cpp" line="23"/>
        <source>Poor compatibility for parts of old graphics cards.</source>
        <translation>Слаба компатибилност са делом старијих графичких картица.</translation>
    </message>
    <message>
        <location filename="../resolutions/resolution.cpp" line="26"/>
        <source>Best compatibility for all Intel graphics cards to accelerate, but performance is relatively weak.</source>
        <translation>Највећа компатибилност за убрзање са свим Интеловим графичким картицама, али учинак је релативно слаб.</translation>
    </message>
    <message>
        <location filename="../resolutions/resolution.cpp" line="27"/>
        <source>Intel Acceleration Mode</source>
        <translation>Intel режим убрзања</translation>
    </message>
    <message>
        <location filename="../resolutions/resolution.cpp" line="28"/>
        <source>Use Intel acceleration mode</source>
        <translation>Користи Intel режим убрзања</translation>
    </message>
    <message>
        <location filename="../resolutions/resolution.cpp" line="29"/>
        <source>Speed up the graphics card with better performance, but unstable in some cards with screen flashing.</source>
        <translation>Убрзајте графичку картицу са бољим учинком, али нестабилно са неким картицама уз треперење екрана.</translation>
    </message>
    <message>
        <location filename="../resolutions/resolution.cpp" line="31"/>
        <source>Use Bumblebee Solution</source>
        <translation>Користи Bumblebee решење</translation>
    </message>
    <message>
        <location filename="../resolutions/resolution.cpp" line="32"/>
        <source>Bumblebee Solution</source>
        <translation>Bumblebee решење</translation>
    </message>
    <message>
        <location filename="../resolutions/resolution.cpp" line="33"/>
        <source>Save power to reduce power consumption.</source>
        <translation>Штедите енергију да смањите потрошњу.</translation>
    </message>
    <message>
        <location filename="../resolutions/resolution.cpp" line="35"/>
        <source>Use NV-PRIME Solution</source>
        <translation>Користи NV-PRIME решење</translation>
    </message>
    <message>
        <location filename="../resolutions/resolution.cpp" line="36"/>
        <source>PRIME Solution</source>
        <translation>PRIME решење</translation>
    </message>
    <message>
        <location filename="../resolutions/resolution.cpp" line="37"/>
        <source>For laptops with hybrid graphics, having best performance but must work with closed-source driver.</source>
        <translation>За преносне рачунаре са хибридном графиком. Има најбољи учинак, али мора радити са власничким управљачким програмом.</translation>
    </message>
</context>
<context>
    <name>ResolutionWidget</name>
    <message>
        <location filename="../widgets/resolutionwidget.cpp" line="118"/>
        <source>Version: </source>
        <translation>Верзија:</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../installer/main.cpp" line="37"/>
        <source>Congratulations, you have switched to %1, please reboot to take effect.</source>
        <translation>Честитамо! Прешли сте на %1. Поново покрените да ступи на снагу.</translation>
    </message>
    <message>
        <location filename="../installer/main.cpp" line="40"/>
        <source>Cancel</source>
        <translation>Откажи</translation>
    </message>
    <message>
        <location filename="../installer/main.cpp" line="41"/>
        <source>Reboot</source>
        <translation>Поново покрени</translation>
    </message>
    <message>
        <location filename="../installer/main.cpp" line="58"/>
        <source>Auto restore to %2 after failed to switch to %1</source>
        <translation>Аутоматски враћено на %2 након неуспешног преласка на %1</translation>
    </message>
    <message>
        <location filename="../installer/main.cpp" line="61"/>
        <source>Submit Feedback</source>
        <translation>Повратне информације</translation>
    </message>
    <message>
        <location filename="../installer/main.cpp" line="69"/>
        <source>Updating the driver, please wait...</source>
        <translation>Ажурирање управљача, молимо сачекајте...</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="25"/>
        <source>Deepin Graphics Driver Manager</source>
        <translation>Управник Управљачких Програма</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="26"/>
        <source>Deepin Graphics Driver Manager is a compact and easy to use graphics driver management tool. It includes graphics card hardware detection, graphics driver installation, graphics driver solution switching,  graphics driver automatic recovery and other functions.</source>
        <translation>Дипин Управник Управљачких Програма је лак за коришћење и компактан алат за управљање графичким управљачким програмима. То укључује откривање графичких картица, инсталацију графичких управљача, пребацивање између решења графичких управљача, самосталан опоравак графичких управљача и друге функције.</translation>
    </message>
</context>
</TS>
